@@ -516,12 +516,8 @@ class Mailing:
 
     @classmethod
     def _from_json(cls, json: dict):
-        recipients = json['report']['recipients']
         return cls(
             id=json['id'],
-            amount_charged=int(json['amount_charged']),
-            status=MailingStatus(json['status']),
-            date_created=helpers.to_datetime(json['created']),
         )
 
 class Contact:
